import { NgxSpinnerService } from 'ngx-spinner';
import { DashboardService } from './../../shared/dashboard.service';
import { HttpClient } from '@angular/common/http';
import { AuthServiceService } from './../../shared/auth-service.service';
import { ActivatedRoute, Params } from '@angular/router';
import { Component, OnInit, ViewChild } from '@angular/core';
import { NgForm } from '@angular/forms';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-add-request',
  templateUrl: './add-request.component.html',
  styleUrls: ['./add-request.component.css']
})
export class AddRequestComponent implements OnInit {

  constructor(private route: ActivatedRoute, 
    private http: HttpClient,
    private toastr: ToastrService,
    private dashBoardSer: DashboardService,
    private spiner: NgxSpinnerService,
    private authService: AuthServiceService) { }

  visitorId: number;
  departments = [];
  departmentsId = [];
  checkSaveClick: boolean = false;
  requestId: number;

  @ViewChild('f') addRequestFrom: NgForm;


  dataForm = {
    type: '',
    specialization_name: '',
    specific_specialization: '',
    university: '',
    level: '',
    training_period: '',
    registration_number: '',
    authority_card_number: '',
    functional_number: '',
    contract_type: '',
    organization_affiliated_with: '',
    department1: '',
    department2: '',
    department3: '',
  }
  
  files = [{
    title : '',
    file: '',
    file_type: '',
    nameFile: '',
  }]

  attachments_ids = []; //for edit mode;

  ngOnInit() {

    this.authService.checkExternalFooter = false;
    this.authService.arabicTemplate = true; //to make footer is arabic all time
    //show / hide notification search in header
    this.authService.notificationLogin = true;
    this.authService.showSearchHeader = false;
    this.authService.showHeaderLogin = false;
    this.authService.showHeaderDashBoard = true;
    this.authService.showDashboardHeader = true;
    this.authService.internalHeader = false;


    this.route.params.subscribe(
      (params: Params) => {
        this.visitorId = +params['visitorId'];
      }
    );

    //get id of request in edit mode
    this.route.params.subscribe(
    (params: Params) => {
      this.requestId = params['requestId'];
      if(this.requestId) {
        this.spiner.show();
        this.http.get(this.authService.pathApi + '/get_request/' + this.requestId).subscribe(
          (responce) => {
            console.log(responce);
            this.dataForm.type = responce['data']['request'].type;
            this.dataForm.specialization_name = responce['data']['request'].specialization_name;
            this.dataForm.specific_specialization = responce['data']['request'].specific_specialization;
            this.dataForm.university = responce['data']['request'].university;
            this.dataForm.level = responce['data']['request'].level;
            this.dataForm.training_period = responce['data']['request'].training_period;

            if(responce['data']['request'].departments.length > 0) {
              if(responce['data']['request'].departments[0].department_id) {
                this.dataForm.department1 = responce['data']['request'].departments[0].department_id;
              }
              if(responce['data']['request'].departments[1].department_id) {
                this.dataForm.department2 = responce['data']['request'].departments[1].department_id;
              }
              if(responce['data']['request'].departments[2].department_id) {
                this.dataForm.department3 = responce['data']['request'].departments[2].department_id;
              }
            }

            if(responce['data']['request'].attachments.length > 0) {
              for(let i = 0; i < responce['data']['request'].attachments.length; i++) {
                this.attachments_ids.push(responce['data']['request'].attachments[i].id);
              }
              console.log('attachements ids', this.attachments_ids);
            } else {
              console.log('no attachements user add !');
            }

            this.spiner.hide();
          },
          (error) => {
            console.log(error);
          }
        )
      }
    }
  );

    this.http.get(this.authService.pathApi + '/training_adminstration_departments').subscribe(
      (responce) => {
        this.departments = responce['departments'];
        console.log(this.departments);
      },
      (error) => {
        console.log(error);
      }
    );

  }



 plusImage() {
   this.files.push({
     title: '',
     file: '',
     file_type: '',
     nameFile: '',
   });
   console.log(this.files);
 }

 onFileChanges(event, index:number) {
   console.log(event);
   console.log(index);
   this.files[index].nameFile = event[0].name.substring(0,20) + '....';
   this.files[index].file = event[0].base64;
   this.files[index].file_type = event[0].type.split('/')[1];
   console.log(this.files);
 }

 onDeleteFile(fileData, index:number) {
   console.log(fileData);
   console.log(index);
   this.files.splice(index , 1);
 }

 changeDepartment(event, typeSelect) {
   console.log(event.target.value);
   if(typeSelect == 1) {
    this.departmentsId[0] = event.target.value;
   } else if(typeSelect == 2) {
    this.departmentsId[1] = event.target.value;
   } else if(typeSelect == 3) {
    this.departmentsId[2] = event.target.value;
   }

  
   
    console.log(this.departmentsId);
    for(let i = 0; i < this.departmentsId.length; i++) {
      if(this.departmentsId[i] == this.departmentsId[i+1]) {
        this.toastr.warning('يوجد أقسام متشابهه ، يجب أن تكون جميه الاقسام مختلفه');
        this.checkSaveClick = true;
        break;
      } else {
        this.checkSaveClick = false;
      }
    }
 }

 changeType(event) {
   this.dataForm.type = event.target.value;
   console.log(this.dataForm.type);
 }

 onSubmitted() {

  //remove fileName from files and remove file is empty 
    for(let i = 0; i < this.files.length; i++) {
     delete this.files[i].nameFile;
     if(this.files[i].file_type){
      this.files[i].file_type = this.files[i].file_type.toLowerCase();
     }
     if(this.files[i].file == '') {
      //this.files.splice(this.files.indexOf(this.files[i], 1));
      console.log('empty number ' , i);  
      this.files.splice(i , 1);
     }
    }
    
    console.log(this.files);
    this.addRequestFrom.value['attachments'] = this.files;

    //store departments in object save
    this.addRequestFrom.value['departments_ids'] = [];

    if(this.addRequestFrom.value['department1']) {
      console.log('1');
      this.addRequestFrom.value['departments_ids'].push(this.addRequestFrom.value['department1']);
      //delete this.addRequestFrom.value['department1'];
    }
    if(this.addRequestFrom.value['department2']) {
     console.log('2');
     this.addRequestFrom.value['departments_ids'].push(this.addRequestFrom.value['department2']);
     //delete this.addRequestFrom.value['department2'];
   }
   if(this.addRequestFrom.value['department3']) {
     console.log('3');
     this.addRequestFrom.value['departments_ids'].push(this.addRequestFrom.value['department3']);
     //delete this.addRequestFrom.value['department3'];
   }


   if(this.requestId) {
    //edit mode
    if(this.addRequestFrom.value['departments_ids'].length == 0 ) {
      this.toastr.warning('من فضلك ، قم بإختيار قسم كحد أدني !');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['registration_number'] == '') {
      this.toastr.warning('قم بإختيار رقم التسجيل !');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['authority_card_number'] == '') {
      this.toastr.warning('قم بإختيار  رقم البطاقه الهنيه !');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['functional_number'] == '') {
      this.toastr.warning('قم بإختيار الرقم الوظيفي!');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['contract_type'] == '') {
      this.toastr.warning('قم بإختيار نوع العقد !');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['organization_affiliated_with'] == '') {
      this.toastr.warning('الجهه التابع لها المتدرب !');
    } else if(this.addRequestFrom.value['attachments'].length > 0){
      for(let i = 0; i < this.addRequestFrom.value['attachments'].length; i++) {
        if(this.addRequestFrom.value['attachments'][i].file_type != 'pdf' || this.addRequestFrom.value['attachments'][i].title == "") {
          this.toastr.warning(  ' ان يكون صيغه الملف ' +  'PDF' + (i+1) );
        }
      }
        delete this.addRequestFrom.value['department1'];
        delete this.addRequestFrom.value['department2'];
        delete this.addRequestFrom.value['department3'];
        console.log('successsss edit ' , this.addRequestFrom.value);
        // this.dashBoardSer.addItem(this.addRequestFrom.value,'request').subscribe(
        //   (responce) => {
        //     console.log(responce);
        //     this.toastr.success('تم التعديل بنحاج');
        //   },
        //   (error) => {
        //     console.log(error);
        //     this.toastr.error('خطأ في التعديل !');
        //   }
        // );
    } else {
        delete this.addRequestFrom.value['department1'];
        delete this.addRequestFrom.value['department2'];
        delete this.addRequestFrom.value['department3'];
        console.log('successsss edit ' , this.addRequestFrom.value);
        // this.dashBoardSer.editItem(this.requestId, this.addRequestFrom.value,'request').subscribe(
        //   (responce) => {
        //     console.log(responce);
        //     this.toastr.success('تم التعديل بنحاج');
        //   },
        //   (error) => {
        //     console.log(error);
        //     console.log(error.error['error']);
        //     if(error.error['error'] == 'can not add new request untill old one done') {
        //       this.toastr.warning('لا يمكن التعديل طلب جديد ، حتي يتم إجراءات علي الطلب السابق ، شكراً');
        //     } else {
        //       this.toastr.error('يوجد مشكله في السرفر ، سيتم معالجتها لاحقاً');
        //     }
        //   }
        // );
    }
   } else {
     
    this.addRequestFrom.value['user_id'] = this.visitorId;//add id of user in object
    //add mode
    if(this.addRequestFrom.value['departments_ids'].length == 0 ) {
      this.toastr.warning('من فضلك ، قم بإختيار قسم كحد أدني !');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['registration_number'] == '') {
      this.toastr.warning('قم بإختيار رقم التسجيل !');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['authority_card_number'] == '') {
      this.toastr.warning('قم بإختيار  رقم البطاقه الهنيه !');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['functional_number'] == '') {
      this.toastr.warning('قم بإختيار الرقم الوظيفي!');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['contract_type'] == '') {
      this.toastr.warning('قم بإختيار نوع العقد !');
    } else if(this.addRequestFrom.value['type'] == 'fellowship' && this.addRequestFrom.value['organization_affiliated_with'] == '') {
      this.toastr.warning('الجهه التابع لها المتدرب !');
    } else if(this.addRequestFrom.value['attachments'].length > 0){
      for(let i = 0; i < this.addRequestFrom.value['attachments'].length; i++) {
        if(this.addRequestFrom.value['attachments'][i].file_type != 'pdf' || this.addRequestFrom.value['attachments'][i].title == "") {
          this.toastr.warning(  ' ان يكون صيغه الملف ' +  'PDF' + (i+1) );
        }
      }
      delete this.addRequestFrom.value['department1'];
        delete this.addRequestFrom.value['department2'];
        delete this.addRequestFrom.value['department3'];
        console.log('successsss save ' , this.addRequestFrom.value);
        this.dashBoardSer.addItem(this.addRequestFrom.value,'request').subscribe(
          (responce) => {
            console.log(responce);
            this.toastr.success('تم الإضافه بنحاج');
          },
          (error) => {
            console.log(error);
            this.toastr.error('خطأ في الإضافه !');
          }
        );
    } else {
        delete this.addRequestFrom.value['department1'];
        delete this.addRequestFrom.value['department2'];
        delete this.addRequestFrom.value['department3'];
        console.log('successsss save ' , this.addRequestFrom.value);
        this.dashBoardSer.addItem(this.addRequestFrom.value,'request').subscribe(
          (responce) => {
            console.log(responce);
            this.toastr.success('تم الإضافه بنحاج');
          },
          (error) => {
            console.log(error);
            console.log(error.error['error']);
            if(error.error['error'] == 'can not add new request untill old one done') {
              this.toastr.warning('لا يمكن إضافه طلب جديد ، حتي يتم إجراءات علي الطلب السابق ، شكراً');
            } else {
              this.toastr.error('يوجد مشكله في السرفر ، سيتم معالجتها لاحقاً');
            }
          }
        );
    }
   }

 }

}
